@@ -32,6 +32,7 @@ import sys
 
 class Camera(BaseCamera):
     video_source = 0
+    histomean = 50
 
     @staticmethod
     def init_cam(  ):
@@ -332,9 +333,10 @@ class Camera(BaseCamera):
 
                     # ----------  I need to calculate histogram before labels...
                     if histogram: # just calculate a number on plain frame
-                        hmean = senh.histo_mean( )
-                        #print("i... histo value:", hmean)
-                        tune_histo(cc, hmean )
+                        hmean = senh.histo_mean( ) # hmean STRING NOW
+                        # notwrk #self.histomean = hmean # when called from direct...
+                        ##print("i... histo value:", hmean)
+                        ##tune_histo(cc, hmean )
 
                     # ---------- before anything - we decode the web command EXECUTE EXECUTION
 
@@ -452,15 +454,15 @@ class Camera(BaseCamera):
                     if framekind in ["detect","delta","histo"]:
                         senh.setbox(f"DISP {framekind}",senh.DISP)
                     if average>0:
-                        senh.setbox(f"acc {average}",  senh.avg)
+                        senh.setbox(f"a {average}",  senh.avg)
                     if blur>0:
-                        senh.setbox(f"blr  {blur}",  senh.blr)
+                        senh.setbox(f"b  {blur}",  senh.blr)
                     if threshold>0:
-                        senh.setbox(f"trh  {threshold}",  senh.trh)
+                        senh.setbox(f"t  {threshold}",  senh.trh)
                     if timelaps>0:
-                        senh.setbox(f"laps {timelaps}",  senh.lap)
+                        senh.setbox(f"l {timelaps}",  senh.lap)
                     if histogram:
-                        senh.setbox(f"his {hmean:3.0f}",  senh.hist)
+                        senh.setbox(f"h {hmean}",  senh.hist)
                     if speedx!=0:
                         #print(speedx)
                         senh.setbox(f"x {speedx:.3f}",  senh.speedx)
