@@ -631,7 +631,8 @@ class Stream_Enhancer:
 
         framegray = cv2.cvtColor(self.frame, cv2.COLOR_BGR2GRAY)
 
-        hist_gray = cv2.calcHist([framegray], [0], None, [BINS], [0, 255])
+        # images; channels; mask none; histSize [BINS]
+        hist_gray = cv2.calcHist([framegray], [0], None, [BINS], [0, 256])
         # cv2.normalize(hist_gray,hist_gray,0,255,cv2.NORM_MINMAX)
 
         #hist_gray = hist_gray/hist_gray.max() # norm 1
@@ -641,12 +642,20 @@ class Stream_Enhancer:
         #print( hist_gray[:9],  bins[:9]  , len(hist_gray), len(bins) , type(hist_gray), type(bins) )
 
         # strange problem WITH 046d:080f  Webcam C120
-        #print(f"                     bins={len(bins)}  len={len(hist_gray)}")
+        #print(f"hg                     binslen={len(bins)}=1; BINS={BINS}  lenHG={len(hist_gray)}")
         sumhist = hist_gray.sum()
-        #print(f"                     sumhist = {sumhist}")
-        if sumhist<1:
-            return 100 # I DONT KNOW WHAT IS THIS
-        mean = np.dot( bins, hist_gray )[0][0]/sumhist/2.55
+        #print(f"hg                     sumhist = {sumhist} all the same!")
+
+
+        black = (hist_gray[0] + hist_gray[1] )/2
+        white = (hist_gray[-1]+hist_gray[-2] )/2
+
+        #print(f"hg              {max(hist_gray)} - {min(hist_gray)} wh{white} blk2{black}")
+        #if sumhist<1:
+        #    return 100 # I DONT KNOW WHAT IS THIS
+        mean = np.dot( bins, hist_gray )
+        #print("MEAN",mean)
+        mean = round(100*mean[0][0]/sumhist/BINS) # min is bin 1, max is bin BINS.
         #print("MEAN",mean)
         #print( "LEN TYPE", len(mean),type(mean) )
 
@@ -658,7 +667,18 @@ class Stream_Enhancer:
         # max1 = hist_gray.max() #/len(hist_gray)
         #print(f"i... .flattened gray    {mean}")
         #  {min1:.1f} {max1:.1f}
-        return mean  #/255*100
+
+        BW = ""
+        if white>100: BW=BW+"W"
+        elif white>0: BW=BW+"w"
+
+        if black>100: BW=BW+"B"
+        elif black>0: BW=BW+"b"
+
+        return f"{mean:.0f}{BW}"  #/255*100
+
+
+
 
     def zoom(self, scale, x=None,y=None):
         #scale = zoom
@@ -730,7 +750,7 @@ class Stream_Enhancer:
 # --------------------------------------------------------save avi ------------
     def save_avi(self, seconds =  1, name = "" ):
         """
-
+        seconds for timelaps  ;   -1 with name="dm" for detectmotion
         """
         #print("i... save_avi", seconds, name)
         # -------------- one shot
