@@ -443,7 +443,7 @@ def display2(videodev, save = False,
                                     stream_length = int( (b+2-a)*0.9 ) # expected length
 
                                     ret_val=1
-                                    print("{:.1f}k #{:06d}/{} {:4.1f}Mb/s {}fps rec{} web{} {}".format(
+                                    print("{:.1f}k #{:06d}/{} {:4.1f}Mb/s {:2d}fps {} w{} {}".format(
                                         # len(bytex)/1024,
                                         stream_length/1024,
                                         frame_num,
