@@ -103,6 +103,7 @@ class V4L2_Control:
             try:
                 sp.check_output(['v4l2-ctl', '-d', self.device, '--set-ctrl=' + self.name + '=' + str(value)]).decode("utf-8")
                 self.value = value
+                time.sleep(0.1) # i want to see a blink ??
                 return 0
             except sp.CalledProcessError as e:
                 print(
@@ -434,8 +435,8 @@ def set_gem(cc, gain=None, expo=None, mmaga=None):
                 print(f"i... current gamma {gm}   range {minm}, {maxm}")
 
                 gm = int( mmaga * (maxm-minm)+minm)
-                if ga>maxg: gm=maxm
-                if ga<ming: gm=minm
+                if gm>maxm: gm=maxm
+                if gm<minm: gm=minm
                 print("i... new gm= ",gm)
 
                 cc.set_gamma(gm)
