@@ -641,8 +641,8 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
         #     frame = frame1
         #     # frame = cv2.add( frame, frame1, mask = frame_mask_inv )
 
-        if not(frame is None):
-            frame=cv2.imencode('.jpg', frame)[1].tobytes()
+        if not(frame is None):  # 95 is default quality
+            frame=cv2.imencode('.jpg', frame, [cv2.IMWRITE_JPEG_QUALITY, 95])[1].tobytes()
         else:
             continue
 
